API docs for “spamfighter.rules.test.test_frequency.FrequencyRulesTestCase”

# Class s.r.t.t.FrequencyRulesTestCase(unittest.TestCase):

Part of spamfighter.rules.test.test_frequency View Source View In Hierarchy

Тест на `spamfighter.rules.frequency`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testCalculateMD5 | Undocumented
Method | testClearMessage | Undocumented
Method | testFrequencyCheckOneMessage | Undocumented
Method | testCountMessages | Undocumented
Method | testFrequencyCheckOneUser | Undocumented
Method | testCountUserMessages | Undocumented
Method | testCountIPMessages | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testCalculateMD5(self): (source)
Undocumented
def testClearMessage(self): (source)
Undocumented
def testFrequencyCheckOneMessage(self): (source)
Undocumented
def testCountMessages(self): (source)
Undocumented
def testFrequencyCheckOneUser(self): (source)
Undocumented
def testCountUserMessages(self): (source)
Undocumented
def testCountIPMessages(self): (source)
Undocumented